# -*- coding: utf-8 -*-
# ~ Jesse K. Rubin ~ Pretty Useful Python

from typing import Union

def safepath(filepath: str): ...
def sstring(filepath: str, string: str) -> None: ...
def sstr(filepath: str, string: str) -> None: ...
def savings(filepath: str, string: str) -> None: ...
def lstring(filepath: str): ...
def lstr(filepath: str): ...
def sjson(filepath: str, data: Union[list, dict], min: bool = ...) -> None: ...
def save_jasm(filepath: str, data: Union[list, dict], min: bool = ...): ...
def sjasm(filepath: str, data: Union[list, dict], min: bool = ...): ...
def spak(filepath: str, data: Union[list, dict], min: bool = ...): ...
def ljson(filepath: str): ...
def load_jasm(filepath: str): ...
def ljasm(filepath: str): ...
def lpak(filepath: str): ...
def touch(filepath: str) -> None: ...
